---
authors:
  - Zhiyuan Chen
date: 2024-05-04
---

# datasets

`datasets` provide a collection of widely used datasets.

## Available Datasets

### DeoxyriboNucleic Acid (DNA)

- [GeneCode](datasets/genecode.md)

### RiboNucleic acid (RNA)

- [RNACentral](datasets/rnacentral.md)
- [Rfam](datasets/rfam.md)
- [bpRNA-1m](datasets/bprna.md)
